@@ -1,6 +1,7 @@
+import os
 import json
 import ipywidgets
-import os
+import ipyvolume
 
 template = """<!DOCTYPE html>
 <html lang="en">
@@ -125,14 +126,22 @@ def embed_html(filename, widgets, drop_defaults=False, all=False, title="ipyvolu
     with open(filename, "w") as f:
         # collect the state of all relevant widgets
         state = {}
-        if all:
-            state = ipywidgets.Widget.get_manager_state(drop_defaults=drop_defaults)["state"]
-        for widget in widgets:
-            if not all:
-                get_state(widget, state, drop_defaults=drop_defaults)
-        # it may be that other widgets refer to the collected widgets, such as layouts, include those as well
-        while add_referring_widgets(state):
-            pass
+        previous = 0 + ipyvolume.serialize.performance
+        try:
+            # we cannot serialize binary buffers yet into the json format, so go back to json
+            # style, and afterwards set it back
+            ipyvolume.serialize.performance = 0
+            if all:
+                state = ipywidgets.Widget.get_manager_state(drop_defaults=drop_defaults)["state"]
+            for widget in widgets:
+                if not all:
+                    get_state(widget, state, drop_defaults=drop_defaults)
+            # it may be that other widgets refer to the collected widgets, such as layouts, include those as well
+            while add_referring_widgets(state):
+                pass
+        finally:
+            ipyvolume.serialize.performance = previous
+
         values = dict(extra_script_head="", body_pre="", body_post="")
         values.update(kwargs)
         widget_views = ""
@@ -150,4 +159,3 @@ def embed_html(filename, widgets, drop_defaults=False, all=False, title="ipyvolu
                            widget_views=widget_views))
         html_code = template.format(**values)
         f.write(html_code)
-
