@@ -48,7 +48,7 @@ def figure(key=None, width=400, height=500, lighting=True, controls=True, debug=
 		current.figure = current.figures[key]
 		current.container = current.containers[key]
 	else:
-		current.figure = volume.VolumeRendererThree(volume_data=None, width=width, height=height, **kwargs)
+		current.figure = volume.Figure(volume_data=None, width=width, height=height, **kwargs)
 		current.container = ipywidgets.VBox()
 		current.container.children = [current.figure]
 		if key is not None:
@@ -269,13 +269,13 @@ def volshow(data, lighting=False, data_min=None, data_max=None, tf=None, stereo=
 	:param controls: add controls for lighting and transfer function or not
 	:return:
 	"""
+	vol = gcf()
 	if tf is None:
-		tf = transfer_function(level, opacity, level_width, controls=controls)
+		tf = vol.tf or transfer_function(level, opacity, level_width, controls=controls)
 	if data_min is None:
 		data_min = np.nanmin(data)
 	if data_max is None:
 		data_max = np.nanmax(data)
-	vol = gcf()
 	vol.tf = tf
 	vol.data_min = data_min
 	vol.data_max = data_max
